import pathlib

import click.testing

from dsw.tdk import main


def test_verify_ok(fixtures_path: pathlib.Path):
    runner = click.testing.CliRunner()
    template_path = fixtures_path / 'test_example01'
    result = runner.invoke(main, args=['verify', template_path.as_posix()])
    assert result.exit_code == 0
    assert 'The template is valid!' in result.output
    assert 'Test template 01' in result.output


def test_verify_missing_attrs(fixtures_path: pathlib.Path):
    runner = click.testing.CliRunner()
    template_path = fixtures_path / 'test_faulty01'
    result = runner.invoke(main, args=['verify', template_path.as_posix()])
    assert result.exit_code == 1
    assert 'Could not load local template' in result.output
    assert 'Unable to load template using' in result.output


def test_verify_no_readme(fixtures_path: pathlib.Path):
    runner = click.testing.CliRunner()
    template_path = fixtures_path / 'test_faulty02'
    result = runner.invoke(main, args=['verify', template_path.as_posix()])
    assert result.exit_code == 1
    assert 'Could not load local template' in result.output
    assert 'README file "README.md" cannot be loaded' in result.output


def test_verify_invalid(fixtures_path: pathlib.Path):
    runner = click.testing.CliRunner()
    template_path = fixtures_path / 'test_faulty03'
    result = runner.invoke(main, args=['verify', template_path.as_posix()])
    assert result.exit_code == 0
    assert 'The template is invalid!' in result.output
    assert 'template_id: Template ID may contain only letters, numbers, and dash' in result.output
    assert 'organization_id: Organization ID may contain only letters, numbers, and period' in result.output
    assert 'version: Version must be in semver format' in result.output
    assert 'name: Missing but it is required' in result.output
    assert 'description: Missing but it is required' in result.output
    assert 'metamodel_version: It must be positive integer' in result.output



import pathlib

import click.testing

from dsw.tdk import main


def test_package_ok(fixtures_path: pathlib.Path, tmp_path: pathlib.Path):
    runner = click.testing.CliRunner()
    template_path = fixtures_path / 'test_example01'
    with runner.isolated_filesystem(temp_dir=tmp_path) as isolated_dir:
        root_dir = pathlib.Path(isolated_dir)
        zip_file = root_dir / 'my-template.zip'

        result = runner.invoke(main, args=['package', template_path.as_posix(), '-o', 'my-template.zip'])
        assert result.exit_code == 0
        assert zip_file.exists() and zip_file.is_file()


def test_package_without_force(fixtures_path: pathlib.Path, tmp_path: pathlib.Path):
    runner = click.testing.CliRunner()
    template_path = fixtures_path / 'test_example01'
    with runner.isolated_filesystem(temp_dir=tmp_path) as isolated_dir:
        root_dir = pathlib.Path(isolated_dir)
        zip_file = root_dir / 'my-template.zip'
        zip_file.write_bytes(b'foo')

        result = runner.invoke(main, args=['package', template_path.as_posix(), '-o', 'my-template.zip'])
        assert result.exit_code == 1
        assert zip_file.exists() and zip_file.is_file()
        assert zip_file.read_bytes() == b'foo'


def test_package_with_force(fixtures_path: pathlib.Path, tmp_path: pathlib.Path):
    runner = click.testing.CliRunner()
    template_path = fixtures_path / 'test_example01'
    with runner.isolated_filesystem(temp_dir=tmp_path) as isolated_dir:
        root_dir = pathlib.Path(isolated_dir)
        zip_file = root_dir / 'my-template.zip'
        zip_file.write_bytes(b'foo')

        result = runner.invoke(main, args=['package', template_path.as_posix(), '-o', 'my-template.zip', '-f'])
        assert result.exit_code == 0
        assert zip_file.exists() and zip_file.is_file()
        assert zip_file.read_bytes() != b'foo'


def test_package_faulty01(fixtures_path: pathlib.Path, tmp_path: pathlib.Path):
    runner = click.testing.CliRunner()
    template_path = fixtures_path / 'test_faulty01'
    with runner.isolated_filesystem(temp_dir=tmp_path) as isolated_dir:
        root_dir = pathlib.Path(isolated_dir)
        zip_file = root_dir / 'my-template.zip'

        result = runner.invoke(main, args=['package', template_path.as_posix(), '-o', 'my-template.zip'])
        assert result.exit_code == 1
        assert not zip_file.exists()



# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.10.6~d3420d2',
    built_at='2024-09-16 12:27:47Z',
    sha='d3420d2752fd7ac579779419711e46df5563b20e',
    branch='HEAD',
    tag='v4.10.6',
)
